OiRA

Help

1. Undirbúningur
3. Greining + Mat
   1. 1 Commercial manned guarding
   2. Ω Aðrar áhættur á vinnustaðnum (ef við á)
      1. Ω.1 The entrance floor is often wet
   - Ekki opnað
   - Frestað
   - Áhættan er ekki til staðar
   - Áhættan er til staðar
4. Aðgerðaáætlun
5. Skýrsla
6. Staða 0%

Hættum sem ekki er fjallað um í verkfærinu er hægt að bæta við hér:

Viltu taka fleiri hættur með í áhættumatið?

Athugið: Til að koma í veg fyrir endurtekningar er mikilvægt að fara í gegnum allt áhættumatið áður en hættum er bætt við.

Ef engum hættum er bætt við veljið þá 'Nei.'

Fyrra Fara í aðgerðaáætlun

Scroll to top
Back

## other-risks.html

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More